@@ -1,5 +1,4 @@
 import tensorflow as tf
-import ipdb
 
 def f1_loss(y_true, y_pred, mode='macro'):
     """Computes differentiable f1 loss fun nction.
@@ -18,7 +17,6 @@ def f1_loss(y_true, y_pred, mode='macro'):
     fn = tf.reduce_sum(y_true * (1 - y_pred), axis=sum_axis)
 
     f1 = 2*tp / (2*tp + fn + fp + 1e-16)
-#     ipdb.set_trace()
     return 1.0 - tf.reduce_mean(f1, axis=sum_axis).numpy()
 
 
